@@ -170,7 +170,6 @@ dialog_cb (GtkAction*           action,
         return;
     }
 
-
     screen = gtk_widget_get_screen (GTK_WIDGET (sapplet->applet));
     appinfo = g_app_info_create_from_commandline ("mate-keyboard-properties --a11y",
                                                   _("Open the keyboard preferences dialog"),
@@ -1317,7 +1316,9 @@ create_applet (MatePanelApplet* applet)
     GtkIconTheme *icon_theme;
     gint icon_size, icon_scale;
 
+#ifndef ENABLE_IN_PROCESS
     g_set_application_name (_("AccessX Status"));
+#endif
 
     sapplet->xkb = NULL;
     sapplet->xkb_display = NULL;
@@ -1635,15 +1636,15 @@ accessx_status_applet_fill (MatePanelApplet* applet)
 
     g_object_connect (sapplet->applet,
                       "signal::destroy", accessx_status_applet_destroy, sapplet,
-                      "signal::change_orient", accessx_status_applet_reorient, sapplet,
-                      "signal::change_size", accessx_status_applet_resize, sapplet,
+                      "signal::change-orient", accessx_status_applet_reorient, sapplet,
+                      "signal::change-size", accessx_status_applet_resize, sapplet,
                       NULL);
 
-    g_signal_connect (sapplet->applet, "button_press_event",
+    g_signal_connect (sapplet->applet, "button-press-event",
                       G_CALLBACK (button_press_cb),
                       sapplet);
 
-    g_signal_connect (sapplet->applet, "key_press_event",
+    g_signal_connect (sapplet->applet, "key-press-event",
                       G_CALLBACK (key_press_cb),
                       sapplet);
 
@@ -1698,9 +1699,9 @@ accessx_status_applet_factory (MatePanelApplet* applet,
     return retval;
 }
 
-MATE_PANEL_APPLET_OUT_PROCESS_FACTORY ("AccessxStatusAppletFactory",
-                                       PANEL_TYPE_APPLET,
-                                       "accessx-status",
-                                       accessx_status_applet_factory,
-                                       NULL)
+PANEL_APPLET_FACTORY ("AccessxStatusAppletFactory",
+                      PANEL_TYPE_APPLET,
+                      "accessx-status",
+                      accessx_status_applet_factory,
+                      NULL)
 
