@@ -15,7 +15,6 @@
 /* The comment for each char list has the html entity names of the chars */
 /* All gunicar codes should end in 0 */
 
-
 /* This is the default list used when starting charpick the first time */
 /* aacute, agrave, eacute, iacute, oacute, frac12, copy*/
 /* static const gchar *def_list = "áàéíñóœ©"; */
@@ -443,7 +442,7 @@ build_table (charpick_data *p_curr_data)
                           G_CALLBACK (chooser_button_clicked),
                           p_curr_data);
 
-        g_signal_connect (button, "button_press_event",
+        g_signal_connect (button, "button-press-event",
                           G_CALLBACK (button_press_hack),
                           p_curr_data->applet);
     }
@@ -494,7 +493,7 @@ build_table (charpick_data *p_curr_data)
                           G_CALLBACK (toggle_button_toggled_cb),
                           p_curr_data);
 
-        g_signal_connect (toggle_button[i], "button_press_event",
+        g_signal_connect (toggle_button[i], "button-press-event",
                           G_CALLBACK (button_press_hack),
                           p_curr_data->applet);
     }
@@ -570,8 +569,6 @@ queue_rebuild (charpick_data *curr_data)
     g_source_set_name_by_id (curr_data->rebuild_id, "[charpick] rebuild_cb");
 }
 
-
-
 static void
 applet_size_allocate (MatePanelApplet *applet,
                       GtkAllocation   *allocation,
@@ -767,7 +764,9 @@ charpicker_applet_fill (MatePanelApplet *applet)
     gchar *string;
     GtkActionGroup *action_group;
 
+#ifndef ENABLE_IN_PROCESS
     g_set_application_name (_("Character Palette"));
+#endif
 
     gtk_window_set_default_icon_name ("accessories-character-map");
 
@@ -799,7 +798,7 @@ charpicker_applet_fill (MatePanelApplet *applet)
                              || (orientation == MATE_PANEL_APPLET_ORIENT_RIGHT);
     build_table (curr_data);
 
-    g_signal_connect (curr_data->applet, "key_press_event",
+    g_signal_connect (curr_data->applet, "key-press-event",
                       G_CALLBACK (key_press_event), curr_data);
 
     utf8_atom = gdk_atom_intern ("UTF8_STRING", FALSE);
@@ -815,21 +814,21 @@ charpicker_applet_fill (MatePanelApplet *applet)
                               GDK_SELECTION_CLIPBOARD,
                               utf8_atom, 0);
 
-    g_signal_connect (curr_data->invisible, "selection_get",
+    g_signal_connect (curr_data->invisible, "selection-get",
                       G_CALLBACK (charpick_selection_handler),
                       curr_data);
 
-    g_signal_connect (curr_data->invisible, "selection_clear_event",
+    g_signal_connect (curr_data->invisible, "selection-clear-event",
                       G_CALLBACK (selection_clear_cb),
                       curr_data);
 
     make_applet_accessible (GTK_WIDGET (applet));
 
     /* session save signal */
-    g_signal_connect (applet, "change_orient",
+    g_signal_connect (applet, "change-orient",
                       G_CALLBACK (applet_change_orient), curr_data);
 
-    g_signal_connect (applet, "size_allocate",
+    g_signal_connect (applet, "size-allocate",
                       G_CALLBACK (applet_size_allocate), curr_data);
 
     g_signal_connect (applet, "destroy",
@@ -875,9 +874,9 @@ charpicker_applet_factory (MatePanelApplet *applet,
     return retval;
 }
 
-MATE_PANEL_APPLET_OUT_PROCESS_FACTORY ("CharpickerAppletFactory",
-                                       PANEL_TYPE_APPLET,
-                                       "char-palette",
-                                       charpicker_applet_factory,
-                                       NULL)
+PANEL_APPLET_FACTORY ("CharpickerAppletFactory",
+                      PANEL_TYPE_APPLET,
+                      "char-palette",
+                      charpicker_applet_factory,
+                      NULL)
 
