@@ -31,6 +31,8 @@
 #include <gdk/gdkkeysyms.h>
 #include <gio/gdesktopappinfo.h>
 
+#include <libmate-desktop/mate-image-menu-item.h>
+
 #include <string.h>
 
 enum {
@@ -383,13 +385,12 @@ drive_button_update (gpointer user_data)
         g_free (color_string);
         g_object_unref (settings);
 
-        guchar red = color.red*255;
-        guchar green = color.green*255;
-        guchar blue = color.blue*255;
+        guchar red   = (guchar) (color.red   * 255.0);
+        guchar green = (guchar) (color.green * 255.0);
+        guchar blue  = (guchar) (color.blue  * 255.0);
 
-        const gdouble ratio = 0.65;
-        gdouble y_start = icon_height * ratio;
-        gdouble x_start = icon_height * (1 + ratio);
+        int y_start = (int) (0.65 * (gdouble) icon_height);
+        int x_start = (int) (1.65 * (gdouble) icon_height);
 
         for (y = y_start; y < icon_height; y++)
             for (x = x_start - y; x < icon_width; x++)
@@ -532,10 +533,10 @@ create_menu_item (DriveButton *self,
 {
     GtkWidget *item, *image;
 
-    item = gtk_image_menu_item_new_with_mnemonic (label);
+    item = mate_image_menu_item_new_with_mnemonic (label);
     if (icon_name) {
         image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+        mate_image_menu_item_set_image (MATE_IMAGE_MENU_ITEM (item), image);
         gtk_widget_show (image);
     }
     if (callback)
