@@ -105,7 +105,6 @@ static void update_cb (GtkAction      *action,
     mateweather_update (gw_applet);
 }
 
-
 static const GtkActionEntry weather_applet_menu_actions [] = {
 	{ "Details", NULL, N_("_Details"),
 	  NULL, NULL,
@@ -342,15 +341,17 @@ void mateweather_applet_create (MateWeatherApplet *gw_applet)
 
     mate_panel_applet_set_flags (gw_applet->applet, MATE_PANEL_APPLET_EXPAND_MINOR);
 
+#ifndef ENABLE_IN_PROCESS
     g_set_application_name (_("Weather Report"));
+#endif
 
     gtk_window_set_default_icon_name ("weather-storm");
 
-    g_signal_connect (gw_applet->applet, "change_orient",
+    g_signal_connect (gw_applet->applet, "change-orient",
                       G_CALLBACK (change_orient_cb),
                       gw_applet);
 
-    g_signal_connect (gw_applet->applet, "size_allocate",
+    g_signal_connect (gw_applet->applet, "size-allocate",
                       G_CALLBACK (size_allocate_cb),
                       gw_applet);
 
@@ -358,11 +359,11 @@ void mateweather_applet_create (MateWeatherApplet *gw_applet)
                       G_CALLBACK (applet_destroy),
                       gw_applet);
 
-    g_signal_connect (gw_applet->applet, "button_press_event",
+    g_signal_connect (gw_applet->applet, "button-press-event",
                       G_CALLBACK(clicked_cb),
                       gw_applet);
 
-    g_signal_connect (gw_applet->applet, "key_press_event",
+    g_signal_connect (gw_applet->applet, "key-press-event",
                       G_CALLBACK (key_press_cb),
                       gw_applet);
 
@@ -523,7 +524,6 @@ gint suncalc_timeout_cb (gpointer data)
     return 0;  /* Do not repeat timeout (will be reset by update_finish) */
 }
 
-
 void mateweather_update (MateWeatherApplet *gw_applet)
 {
     WeatherPrefs prefs;
