@@ -27,6 +27,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
+#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 #include <libnotify/notify.h>
@@ -125,6 +126,9 @@ timer_callback (TimerApplet *applet)
     label = NULL;
     tooltip = NULL;
 
+    if (!GTK_IS_WIDGET (applet->label))
+        return FALSE;
+
     name = g_settings_get_string (applet->settings, NAME_KEY);
     atk_obj = gtk_widget_get_accessible (GTK_WIDGET (applet->applet));
 
@@ -158,7 +162,7 @@ timer_callback (TimerApplet *applet)
             gtk_widget_set_tooltip_text (GTK_WIDGET (applet->label), name);
             gtk_widget_hide (GTK_WIDGET (applet->pause_image));
             atk_object_set_name (atk_obj, label);
-            atk_object_set_description (atk_obj, tooltip);
+            atk_object_set_description (atk_obj, "");
 
             if (g_settings_get_boolean (applet->settings, SHOW_NOTIFICATION_KEY))
             {
@@ -350,15 +354,20 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
 }
 
 static gboolean
-timer_applet_click (TimerApplet *applet)
+timer_applet_click (TimerApplet *applet,  GdkEventButton *event)
 {
-    if (!applet->active && !applet->pause && applet->elapsed)
-        timer_reset_callback (NULL, applet);
-    else if (applet->active && !applet->pause)
-        timer_pause_callback (NULL, applet);
-    else if (!applet->active || applet->pause)
-        timer_start_callback (NULL, applet);
-    return FALSE;
+    if (  event->button == 1)
+    {
+        if (!applet->active && !applet->pause && applet->elapsed)
+            timer_reset_callback (NULL, applet);
+        else if (applet->active && !applet->pause)
+            timer_pause_callback (NULL, applet);
+        else if (!applet->active || applet->pause)
+            timer_start_callback (NULL, applet);
+    return TRUE;
+    }
+    else
+        return FALSE;
 }
 
 static void
@@ -373,7 +382,9 @@ timer_applet_fill (MatePanelApplet* applet_widget)
     TimerApplet *applet;
     AtkObject   *atk_obj;
 
+#ifndef ENABLE_IN_PROCESS
     g_set_application_name (_("Timer Applet"));
+#endif
     gtk_window_set_default_icon_name (APPLET_ICON);
 
     if (!notify_is_initted ())
@@ -419,7 +430,7 @@ timer_applet_fill (MatePanelApplet* applet_widget)
                       G_CALLBACK (timer_applet_destroy),
                       applet);
 
-    g_signal_connect_swapped (applet->applet, "button-release-event",
+    g_signal_connect_swapped (applet->applet, "button-press-event",
                               G_CALLBACK (timer_applet_click),
                               applet);
 
@@ -454,8 +465,8 @@ timer_factory (MatePanelApplet* applet, const char* iid, gpointer data)
 }
 
 /* needed by mate-panel applet library */
-MATE_PANEL_APPLET_OUT_PROCESS_FACTORY("TimerAppletFactory",
-                                      PANEL_TYPE_APPLET,
-                                      "Timer applet",
-                                      timer_factory,
-                                      NULL)
+PANEL_APPLET_FACTORY ("TimerAppletFactory",
+                      PANEL_TYPE_APPLET,
+                      "Timer applet",
+                      timer_factory,
+                      NULL)
